/*
 * @Author: zc
 * @description 司法行政监督
 */
import request from '@/utils/request';
import qs from 'qs';

/**
 * @description 获取工单列表
 * @param params
 * @return {*}
 */
export const getWorkList = (params: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/getorderlist',
		method: 'get',
		params,
		paramsSerializer: (params: any) => qs.stringify(params),
	});
};

/**
 * @description 列表页基础信息
 * @param params
 * @return {*}
 */
export const listBaseData = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/base-data',
		method: 'get',
		params,
	});
};
/**
 * @description 线索核实
 * @param data
 * @return {*}
 */
export const getClues = (data: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/clue_verification',
		method: 'post',
		data,
	});
};
/**
 * @description 线索核实基础信息
 * @return {*}
 */
export const getCluesBaseData = () => {
	return request({
		url: '/api/v1/EnforcementOrder/treelist',
		method: 'get',
	});
};
/**
 * @description 事项分类统计
 * @param params
 * @return {*}
 */
export const eventStatistics = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/event_classification_statistics',
		method: 'get',
		params,
	});
};
/**
 * @description 事项分类统计明细
 * @param params
 * @return {*}
 */
export const eventStatisticsDetail = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/event_classification_statistics_order_list',
		method: 'get',
		params,
	});
};
/**
 * @description 区域排行统计
 * @param params
 * @return {*}
 */
export const areaStatistics = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/regional_classification_statistics',
		method: 'get',
		params,
	});
};
/**
 * @description 区域排行统计明细
 * @param params
 * @return {*}
 */
export const areaStatisticsDetail = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/regional_classification_statistics_order_list',
		method: 'get',
		params,
	});
};
/**
 * @description 执法部门统计
 * @param params
 * @return {*}
 */
export const departmentStatistics = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/enforcement_departmental_processing_statistics',
		method: 'get',
		params,
	});
};
/**
 * @description 执法部门统计明细
 * @param params
 * @return {*}
 */
export const departmentStatisticsDetail = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/enforcement_departmental_processing_statistics_order_list',
		method: 'get',
		params,
	});
};
/**
 * @description 执法部门统计部门明细
 * @param params
 * @return {*}
 */
export const departmentStatisticsDepartmentDetail = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/enforcement_departmental_processing_statistics_child',
		method: 'get',
		params,
	});
};
/**
 * @description 部门满意度统计
 * @param params
 * @return {*}
 */
export const departmentSatisfaction = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/enforcement_visit_org_satisfaction_statistics',
		method: 'get',
		params,
	});
};
/**
 * @description 部门满意度统计明细
 * @param params
 * @return {*}
 */
export const departmentSatisfactionDetail = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/enforcement_visit_org_satisfaction_statistics_order_list',
		method: 'get',
		params,
	});
};
/**
 * @description 部门满意度统计子集明细
 * @param params
 * @return {*}
 */
export const departmentSatisfactionChildDetail = (params?: object) => {
	return request({
		url: '/api/v1/EnforcementOrder/enforcement_visit_org_satisfaction_statistics_child',
		method: 'get',
		params,
	});
};
/**
 * @description 获取区域信息
 * @param params
 * @return {*}
 */
export const getArea = (params?: object) => {
	return request({
		url: '/api/v1/DataScreen/get_system_area',
		method: 'get',
		params,
	});
};
